summaryrefslogtreecommitdiff
path: root/distrib/i386/floppies/upgr/upgrade.sh
diff options
context:
space:
mode:
authorNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
committerNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
commitca20eee8a154b2ffc9df0940a63371bcd284aaed (patch)
tree2be4056cd94f078774d7c965c865f62e5289467a /distrib/i386/floppies/upgr/upgrade.sh
parentd44dfb5d692e3c38d987ca775af156909295c7b3 (diff)
Did some s/NetBSD/OpenBSD/, s/netbsd/bsd/ and $OpenBSD$ additions.
However this stuff is largely related to NetBSD and must be completely redone, if we will make real relases sometime
Diffstat (limited to 'distrib/i386/floppies/upgr/upgrade.sh')
-rw-r--r--distrib/i386/floppies/upgr/upgrade.sh13
1 files changed, 6 insertions, 7 deletions
diff --git a/distrib/i386/floppies/upgr/upgrade.sh b/distrib/i386/floppies/upgr/upgrade.sh
index 2db8fbd6d3a..fbfa4c121dc 100644
--- a/distrib/i386/floppies/upgr/upgrade.sh
+++ b/distrib/i386/floppies/upgr/upgrade.sh
@@ -1,4 +1,5 @@
#!/bin/sh
+# $OpenBSD: upgrade.sh,v 1.4 1996/04/25 21:28:32 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -27,10 +28,8 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# $Id: upgrade.sh,v 1.3 1995/12/14 07:00:15 deraadt Exp $
# NetBSD upgrade script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -48,9 +47,9 @@ getresp() {
fi
}
-echo "Welcome to the NetBSD ${VERSION} upgrade program."
+echo "Welcome to the OpenBSD ${VERSION} upgrade program."
echo ""
-echo "This program is designed to help you put the new version of NetBSD"
+echo "This program is designed to help you put the new version of OpenBSD"
echo "on your hard disk, in a simple and rational way. To upgrade, you"
echo "must have plenty of free space on all partitions which will be"
echo "upgraded. If you have at least 1MB free on your root partition,"
@@ -242,11 +241,11 @@ echo "Done."
echo ""
echo ""
echo "OK! The preliminary work of setting up your disk is now complete,"
-echo "and you can now upgrade the actual NetBSD software."
+echo "and you can now upgrade the actual OpenBSD software."
echo ""
echo "Right now, your hard disk is mounted on /mnt. You should consult"
echo "the installation notes to determine how to load and install the new"
-echo "NetBSD distribution sets, and how to clean up after the upgrade"
+echo "OpenBSD distribution sets, and how to clean up after the upgrade"
echo "software, when you are done."
echo ""
echo "GOOD LUCK!"
@@ -27,10 +28,8 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: upgrade.sh,v 1.3 1995/12/14 07:00:15 deraadt Exp $
-# NetBSD upgrade script.
+# OpenBSD upgrade script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.